@@ -3,9 +3,9 @@
 //! # simple-log format output
 //!
 //! ```bash
-//! 2020-12-07 15:06:03:260570000 [INFO] <json_log:16>:info json simple_log
-//! 2020-12-07 15:06:03:262106000 [WARN] <json_log:17>:warn json simple_log
-//! 2020-12-07 15:06:03:262174000 [ERROR] <json_log:18>:error json simple_log
+//! 2020-12-07 15:06:03.260570000 [INFO] <json_log:16>:info json simple_log
+//! 2020-12-07 15:06:03.262106000 [WARN] <json_log:17>:warn json simple_log
+//! 2020-12-07 15:06:03.262174000 [ERROR] <json_log:18>:error json simple_log
 //! ```
 //!
 //! # Quick Start
@@ -16,12 +16,11 @@
 //! #[macro_use]
 //! extern crate log;
 //!
-//! fn main() -> Result<(), String> {
-//!    simple_log::quick()?;
+//! fn main() {
+//!    simple_log::quick!();
 //!
 //!    debug!("test quick debug");
 //!    info!("test quick info");
-//!    Ok(())
 //!}
 //! ```
 //!
@@ -97,14 +96,20 @@ use log4rs::append::rolling_file::RollingFileAppender;
 use log4rs::config::{Appender, Config, Root};
 use log4rs::encode::pattern::PatternEncoder;
 use once_cell::sync::OnceCell;
+use out_kind::deserialize_out_kind;
 use serde::{Deserialize, Serialize};
 use std::sync::Mutex;
 
-type SimpleResult<T> = std::result::Result<T, String>;
-
 #[cfg(feature = "shadow-rs")]
 pub use shadow_rs::is_debug;
 
+pub type SimpleResult<T> = std::result::Result<T, String>;
+
+const SIMPLE_LOG_FILE: &str = "simple_log_file";
+const SIMPLE_LOG_CONSOLE: &str = "simple_log_console";
+
+const DEFAULT_DATE_TIME_FORMAT: &str = "%Y-%m-%d %H:%M:%S.%f";
+
 /// simple-log global config.
 struct LogConf {
     log_config: LogConfig,
@@ -237,19 +242,15 @@ pub fn get_log_conf() -> SimpleResult<LogConfig> {
     Ok(config)
 }
 
-const SIMPLE_LOG_FILE: &str = "simple_log_file";
-const SIMPLE_LOG_CONSOLE: &str = "simple_log_console";
-
-use out_kind::deserialize_out_kind;
-
 #[derive(Debug, Default, Serialize, Deserialize, Clone, PartialEq)]
 pub struct LogConfig {
-    path: String,
-    level: String,
-    size: u64,
+    pub path: String,
+    pub level: String,
+    pub size: u64,
     #[serde(deserialize_with = "deserialize_out_kind")]
-    out_kind: Vec<OutKind>,
-    roll_count: u32,
+    pub out_kind: Vec<OutKind>,
+    pub roll_count: u32,
+    pub time_format: Option<String>,
 }
 
 impl LogConfig {
@@ -272,6 +273,10 @@ impl LogConfig {
     pub fn get_roll_count(&self) -> u32 {
         self.roll_count
     }
+
+    pub fn get_time_format(&self) -> Option<&String> {
+        self.time_format.as_ref()
+    }
 }
 
 /// The [LogConfig] with builder wrapper.
@@ -350,6 +355,15 @@ impl LogConfigBuilder {
         self
     }
 
+    /// It's optional method.
+    /// Also support default data_time_format:%Y-%m-%d %H:%M:%S.%f
+    ///
+    /// Support data_time_format with link:https://docs.rs/chrono/0.4.19/chrono/naive/struct.NaiveDateTime.html#method.parse_from_str
+    pub fn time_format<S: Into<String>>(mut self, time_format: S) -> LogConfigBuilder {
+        self.0.time_format = Some(time_format.into());
+        self
+    }
+
     /// Constructs a new `LogConfig` .
     ///
     /// # Examples
@@ -363,6 +377,7 @@ impl LogConfigBuilder {
     ///         .size(1 * 100)
     ///        .roll_count(10)
     ///        .level("debug")
+    ///        .time_format("%Y-%m-%d %H:%M:%S.%f")
     ///        .output_file()
     ///        .output_console()
     ///        .build();
@@ -433,16 +448,22 @@ pub fn new(log_config: LogConfig) -> SimpleResult<()> {
 /// #[macro_use]
 /// extern crate log;
 ///
-/// fn main() -> Result<(), String> {
-///     simple_log::quick()?;
+/// fn main() {
+///     simple_log::quick!("info");
 ///
 ///     debug!("test builder debug");
 ///     info!("test builder info");
-///     Ok(())
 /// }
 /// ```
 pub fn quick() -> SimpleResult<()> {
+    quick_log_level(log_level::DEBUG)
+}
+
+pub fn quick_log_level<S: Into<String>>(log_level: S) -> SimpleResult<()> {
+    let level = log_level.into();
+    log_level::validate_log_level(&level)?;
     let mut config = LogConfig::default();
+    config.level = level;
     init_default_log(&mut config);
     init_log_conf(config)?;
     Ok(())
@@ -471,6 +492,7 @@ pub fn console<S: Into<String>>(level: S) -> SimpleResult<()> {
         size: 0,
         out_kind: vec![OutKind::Console],
         roll_count: 0,
+        time_format: Some(DEFAULT_DATE_TIME_FORMAT.to_string()),
     };
     init_log_conf(config)?;
     Ok(())
@@ -505,6 +527,7 @@ pub fn file<S: Into<String>>(path: S, level: S, size: u64, roll_count: u32) -> S
         size,
         out_kind: vec![OutKind::File],
         roll_count,
+        time_format: Some(DEFAULT_DATE_TIME_FORMAT.to_string()),
     };
     init_log_conf(config)?;
     Ok(())
@@ -522,7 +545,7 @@ fn build_config(log: &LogConfig) -> SimpleResult<Config> {
             }
             OutKind::Console => {
                 let console = ConsoleAppender::builder()
-                    .encoder(Box::new(encoder()))
+                    .encoder(Box::new(encoder(log.time_format.as_ref())))
                     .build();
                 config_builder = config_builder
                     .appender(Appender::builder().build(SIMPLE_LOG_CONSOLE, Box::new(console)));
@@ -561,8 +584,15 @@ fn init_default_log(log: &mut LogConfig) {
     }
 }
 
-fn encoder() -> PatternEncoder {
-    PatternEncoder::new("{d(%Y-%m-%d %H:%M:%S:%f)} [{l}] <{M}:{L}>:{m}\n")
+fn encoder(time_format: Option<&String>) -> PatternEncoder {
+    let time_format = if let Some(format) = time_format {
+        format.to_string()
+    } else {
+        DEFAULT_DATE_TIME_FORMAT.to_string()
+    };
+    let mut pattern = format!("{{d({})}} ", time_format);
+    pattern = pattern + "[{l}] <{M}:{L}>:{m}\n";
+    PatternEncoder::new(pattern.as_str())
 }
 
 fn file_appender(log: &LogConfig) -> SimpleResult<Box<RollingFileAppender>> {
@@ -576,7 +606,7 @@ fn file_appender(log: &LogConfig) -> SimpleResult<Box<RollingFileAppender>> {
     let policy = CompoundPolicy::new(Box::new(trigger), Box::new(roll));
 
     let logfile = RollingFileAppender::builder()
-        .encoder(Box::new(encoder()))
+        .encoder(Box::new(encoder(log.time_format.as_ref())))
         .build(log.path.clone(), Box::new(policy))
         .map_err(|e| e.to_string())?;
 
@@ -614,13 +644,33 @@ pub mod log_level {
     /// ```
     ///
     pub fn form_log_level(level: &str) -> LevelFilter {
+        validate_log_level(level).unwrap_or(LevelFilter::Debug)
+    }
+
+    pub fn validate_log_level(level: &str) -> Result<LevelFilter, String> {
         match level.to_lowercase().as_str() {
-            TRACE => LevelFilter::Trace,
-            DEBUG => LevelFilter::Debug,
-            INFO => LevelFilter::Info,
-            WARN => LevelFilter::Warn,
-            ERROR => LevelFilter::Error,
-            _ => LevelFilter::Debug,
+            TRACE => Ok(LevelFilter::Trace),
+            DEBUG => Ok(LevelFilter::Debug),
+            INFO => Ok(LevelFilter::Info),
+            WARN => Ok(LevelFilter::Warn),
+            ERROR => Ok(LevelFilter::Error),
+            _ => {
+                let log_levels = format!("{},{},{},{},{}", TRACE, DEBUG, INFO, WARN, ERROR);
+                Err(format!(
+                    "unknown log_level:{},one of:[{}]",
+                    level, log_levels
+                ))
+            }
         }
     }
 }
+
+#[macro_export]
+macro_rules! quick {
+    () => {
+        $crate::quick_log_level($crate::log_level::DEBUG).unwrap()
+    };
+    ($log_level:expr) => {{
+        $crate::quick_log_level($log_level).unwrap()
+    }};
+}
